@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -12,15 +12,20 @@
 #include <Libkdepim/LineEditCatchReturnKey>
 #include <QLineEdit>
 
+#include <KWindowConfig>
 #include <QDialogButtonBox>
 #include <QHBoxLayout>
 #include <QPointer>
 #include <QPushButton>
 #include <QToolButton>
 #include <QVBoxLayout>
+#include <QWindow>
 
 using namespace KSieveUi;
-
+namespace
+{
+static const char mySelectFlagsListDialogGroupName[] = "SelectFlagsListDialog";
+}
 SelectFlagsListDialog::SelectFlagsListDialog(QWidget *parent)
     : QDialog(parent)
     , mListWidget(new SelectFlagsListWidget(this))
@@ -47,17 +52,18 @@ SelectFlagsListDialog::~SelectFlagsListDialog()
 
 void SelectFlagsListDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SelectFlagsListDialog");
-    const QSize sizeDialog = group.readEntry("Size", QSize(300, 200));
-    if (sizeDialog.isValid()) {
-        resize(sizeDialog);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(300, 200));
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySelectFlagsListDialogGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void SelectFlagsListDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "SelectFlagsListDialog");
-    group.writeEntry("Size", size());
+    KConfigGroup group(KSharedConfig::openStateConfig(), mySelectFlagsListDialogGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
+    group.sync();
 }
 
 void SelectFlagsListDialog::setFlags(const QStringList &list)
