@@ -1,10 +1,9 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
-#ifndef SELECTIMPORTANCECOMBOBOX_H
-#define SELECTIMPORTANCECOMBOBOX_H
+#pragma once
 
 #include <QComboBox>
 
@@ -27,4 +26,3 @@ private:
     void initialize();
 };
 }
-#endif // SELECTIMPORTANCECOMBOBOX_H
