@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -50,7 +50,7 @@ SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *g
     bg->addButton(mMatchAny);
     bg->addButton(mAllMessageRBtn);
 
-    connect(bg, QOverload<QAbstractButton *>::of(&QButtonGroup::buttonClicked), this, &SieveScriptBlockWidget::slotRadioClicked);
+    connect(bg, &QButtonGroup::buttonClicked, this, &SieveScriptBlockWidget::slotRadioClicked);
     mConditions->setLayout(vbox);
 
     mScriptConditionLister = new SieveConditionWidgetLister(mSieveGraphicalModeWidget, this);
@@ -84,9 +84,7 @@ SieveScriptBlockWidget::SieveScriptBlockWidget(SieveEditorGraphicalModeWidget *g
     topLayout->addLayout(newBlockLayout);
 }
 
-SieveScriptBlockWidget::~SieveScriptBlockWidget()
-{
-}
+SieveScriptBlockWidget::~SieveScriptBlockWidget() = default;
 
 void SieveScriptBlockWidget::slotAddBlock()
 {
@@ -248,7 +246,11 @@ void SieveScriptBlockWidget::loadScript(QXmlStreamReader &element, bool onlyActi
     } else {
         bool uniqueTest = false;
         while (element.readNextStartElement()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
             const QStringRef tagName = element.name();
+#else
+            const QStringView tagName = element.name();
+#endif
             if (tagName == QLatin1String("test")) {
                 bool notCondition = false;
                 if (element.attributes().hasAttribute(QLatin1String("name"))) {
